summaryrefslogtreecommitdiffstats
path: root/libtommath/bn_mp_div_2d.c
diff options
context:
space:
mode:
Diffstat (limited to 'libtommath/bn_mp_div_2d.c')
-rw-r--r--libtommath/bn_mp_div_2d.c44
1 files changed, 16 insertions, 28 deletions
diff --git a/libtommath/bn_mp_div_2d.c b/libtommath/bn_mp_div_2d.c
index 912faaf..c47d5ce 100644
--- a/libtommath/bn_mp_div_2d.c
+++ b/libtommath/bn_mp_div_2d.c
@@ -1,52 +1,44 @@
#include "tommath_private.h"
#ifdef BN_MP_DIV_2D_C
-/* LibTomMath, multiple-precision integer library -- Tom St Denis
- *
- * LibTomMath is a library that provides multiple-precision
- * integer arithmetic as well as number theoretic functionality.
- *
- * The library was designed directly after the MPI library by
- * Michael Fromberger but has been written from scratch with
- * additional optimizations in place.
- *
- * SPDX-License-Identifier: Unlicense
- */
+/* LibTomMath, multiple-precision integer library -- Tom St Denis */
+/* SPDX-License-Identifier: Unlicense */
/* shift right by a certain bit count (store quotient in c, optional remainder in d) */
-int mp_div_2d(const mp_int *a, int b, mp_int *c, mp_int *d)
+mp_err mp_div_2d(const mp_int *a, int b, mp_int *c, mp_int *d)
{
mp_digit D, r, rr;
- int x, res;
+ int x;
+ mp_err err;
/* if the shift count is <= 0 then we do no work */
if (b <= 0) {
- res = mp_copy(a, c);
+ err = mp_copy(a, c);
if (d != NULL) {
mp_zero(d);
}
- return res;
+ return err;
}
/* copy */
- if ((res = mp_copy(a, c)) != MP_OKAY) {
- return res;
+ if ((err = mp_copy(a, c)) != MP_OKAY) {
+ return err;
}
/* 'a' should not be used after here - it might be the same as d */
/* get the remainder */
if (d != NULL) {
- if ((res = mp_mod_2d(a, b, d)) != MP_OKAY) {
- return res;
+ if ((err = mp_mod_2d(a, b, d)) != MP_OKAY) {
+ return err;
}
}
/* shift by as many digits in the bit count */
- if (b >= DIGIT_BIT) {
- mp_rshd(c, b / DIGIT_BIT);
+ if (b >= MP_DIGIT_BIT) {
+ mp_rshd(c, b / MP_DIGIT_BIT);
}
- /* shift any bit count < DIGIT_BIT */
- D = (mp_digit)(b % DIGIT_BIT);
+ /* shift any bit count < MP_DIGIT_BIT */
+ D = (mp_digit)(b % MP_DIGIT_BIT);
if (D != 0u) {
mp_digit *tmpc, mask, shift;
@@ -54,7 +46,7 @@ int mp_div_2d(const mp_int *a, int b, mp_int *c, mp_int *d)
mask = ((mp_digit)1 << D) - 1uL;
/* shift for lsb */
- shift = (mp_digit)DIGIT_BIT - D;
+ shift = (mp_digit)MP_DIGIT_BIT - D;
/* alias */
tmpc = c->dp + (c->used - 1);
@@ -77,7 +69,3 @@ int mp_div_2d(const mp_int *a, int b, mp_int *c, mp_int *d)
return MP_OKAY;
}
#endif
-
-/* ref: $Format:%D$ */
-/* git commit: $Format:%H$ */
-/* commit time: $Format:%ai$ */